==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/banners.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("../include/header.inc.php");

$banner_table = "T_Banners";
$banner_path = "banners";

settype($act, "string");
if ($act == "add") {
   $url = KWL_UrlCheck($url);
   if ($url && $img_url) {
      SqlQuery("INSERT INTO $banner_table (url,img_url,alt,rdate) VALUES ('$url','$img_url','$alt',". time() .")");
   }

} elseif ($act == "editok" && $id) {
   $url = KWL_UrlCheck($url);
   $alt = trim($alt);
   if ($url && $img_url) {
      SqlQuery("UPDATE $banner_table SET url = '$url', img_url = '$img_url', alt = '$alt' WHERE id = $id");
   }

} elseif ($act == "active") {
   if (SqlCount("T_Config","Name","Banners")) {
      SqlQuery("UPDATE T_Config SET Value = $Banners WHERE Name = 'Banners'");
   } else {
      SqlQuery("INSERT INTO T_Config (Name,Value) VALUES ('Banners', $Banners)");
   }
   if (SqlCount("T_Config","Name","Banner_location")) {
      SqlQuery("UPDATE T_Config SET Value = $Banner_location WHERE Name = 'Banner_location'");
   } else {
      SqlQuery("INSERT INTO T_Config (Name,Value) VALUES ('Banner_location', $Banner_location)");
   }
   $CONF['Banners'] = $Banners;
   $CONF['Banner_location'] = $Banner_location;

} elseif ($act == "kill" && $id) {
   SqlQuery("DELETE FROM $banner_table WHERE id = $id"); 

} elseif ($act == "scan") {
   $buttons = KWL_GetFileName("$CONF[G_PATH]/$banner_path");
   if (is_array($buttons)) {
      foreach ($buttons as $img) {
         $img_url = "$banner_path/$img";
         if (!SqlCount($banner_table,"img_url",$img_url)) {
            SqlQuery("INSERT INTO $banner_table (img_url,rdate) VALUES ('$img_url',". time() .")");
         }
      }
   }
}

$out = new KWL_Html;
$VAR['Content'] = $out->form_start("admin/banners.php","banners").
                $out->table_start("100%",'',0,0,5).
                "<tr><td>$banner_path/*.* :</td><td>".
                "<a href=\"". $_SERVER['PHP_SELF'] ."?act=scan\">Scan</a></td></tr>".
                "<tr><td>". _BANNER .":</td><td>".
                $out->radio("Banners",array(_NOTUSE,_USE),$CONF['Banners']).
                "</tr><tr><td>". _BANNER_LOCATION .":</td><td>".
                $out->radio("Banner_location",array("header","footer"),$CONF['Banner_location']).
                "<br>(". _BANNER_LOCATION_DESC .
                ")</td></tr><tr><td colspan=\"2\">".
                $out->input_form("hidden","act","active").
                $out->input_form("submit",'',_SAVE_CHANGE).
                "</td></tr>". $out->table_end() . $out->form_end();
                
$VAR['Heading'] = _BANNER;
KWL_DrawMain($VAR);

if ($act == "edit") {
   $rt = SqlQueryFetchArray("select * from $banner_table where id = $id");
   $VAR['Content'] = banner_form($out,$rt);
   $VAR['Heading'] = "<a name=\"banner_edit\">". _BANNER_EDIT ."</a>";
} else {
   $VAR['Content'] = banner_form($out);
   $VAR['Heading'] = _BANNER_ADD;
}
KWL_DrawMain($VAR);

settype($by, "string");
if ($by=="id" || $by=="url" || $by=="alt" || $by=="hits") {
      if ($sort=="asc") { $sort = "$by $sort"; $rsort = "desc"; }
         else if ($sort=="desc") { $sort = "$by $sort"; $rsort = "asc"; }
            else { $sort = "id asc"; $rsort = "desc"; }
} else { $sort = "rdate desc"; $rsort = "desc"; }

$rt = SqlQuery("SELECT * FROM $banner_table ORDER BY $sort");

if (mysql_num_rows($rt)) {
   $VAR['Content'] = $out->table_start("100%",'',1,0,5).
                   "<tr><th><a href=\"". $_SERVER['PHP_SELF'] ."?by=id&sort=$rsort\">no</a></th>".
                   "<th>img</th>".
                   "<th><a href=\"". $_SERVER['PHP_SELF'] ."?by=url&sort=$rsort\">url</a></th>".
                   "<th><a href=\"". $_SERVER['PHP_SELF'] ."?by=alt&sort=$rsort\">". _BANNER_ALT ."</a></th>".
                   "<th><a href=\"". $_SERVER['PHP_SELF'] ."?by=hits&sort=$rsort\">hits</a></th>".
                   "<th>op</th>";
   $no = 1;
   while ($A = mysql_fetch_array($rt)) {
      if (!preg_match('!^http!', $A['img_url'])) $A['img_url'] = "$CONF[G_URL]/$A[img_url]";
      $VAR['Content'] .= "<tr><td>$no</td>".
                       "<td><img src=\"$A[img_url]\" BORDER=\"0\" VSPACE=\"1\" HSPACE=\"1\" ALT=\"". KWL_PrepareHtml($A['alt']) ."\"></td>".
                       "<td><a href=\"$A[url]\" target=\"_blank\">$A[url]</a></td>".
                       "<td>". KWL_PrepareHtml($A['alt']) ."</td>".
                       "<td>". number_format($A['hits']) ."</td>".
                       "<td><A ONCLICK=\"return getconfirm();\" HREF=\"". $_SERVER['PHP_SELF'] ."?act=kill&id=$A[id]\"><IMG SRC=\"$CONF[img_url]/kill.gif\" ALT=\"kill\" BORDER=\"0\"></A>&nbsp;<A HREF=\"". $_SERVER['PHP_SELF'] ."?act=edit&id=$A[id]#banner_edit\"><IMG SRC=\"$CONF[img_url]/edit.gif\" ALT=\"edit\" BORDER=\"0\"></A></td></tr>";
      $no++;
   }
   $VAR['Content'] .= $out->table_end();
   $VAR['Heading'] = _BANNER;
   KWL_DrawMain($VAR);
}
include("../include/footer.inc.php");

function banner_form($out,$A='') {
   if (is_array($A)) {
      if (!preg_match('!^http!', $A['img_url']))
         $A['img_url'] = KWL_GetConf('G_URL') ."/". $A['img_url'];
      $what = "editok";
   } else {
      $what = "add";
      $A['url'] = $A['img_url'] = $A['alt'] = $A['id'] = "";
   }
   
   return $out->form_start("admin/banners.php","banners").
          $out->table_start("100%",0,0,5).
          "<tr>".
          "<td>* Url:</td>".
          "<td>". $out->input_form("text","url",$A['url'],KWL_FormSize(20),255) ."</td></tr>".
          "<td>* Image Url:</td>".
          "<td>". ($A['img_url'] ? "<img src=\"$A[img_url]\" border=\"0\" vspace=\"1\" hspace=\"1\" /><br />" : "") .
          $out->input_form("text","img_url",$A['img_url'],KWL_FormSize(20),255) ."</td></tr>".
          "<tr><td>". _RANDOM_BUTTON_ALT .":</td>".
          "<td>". $out->input_form("text","alt",KWL_PrepareHtml($A['alt']),KWL_FormSize(20),255) ."</td></tr>".
          "<tr><td colspan=\"2\">".
          $out->input_form("hidden","id",$A['id']).
          $out->input_form("hidden","act",$what).
          $out->input_form("submit",'',_SAVE_CHANGE).
          "</td></tr>". $out->table_end() . $out->form_end();
}
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/admin/banners.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("../include/common.inc.php");
include("auth.inc.php");
include("../include/header.inc.php");

$banner_table = "T_Banners";
$banner_path = "banners";

settype($act, "string");
if ($act == "add") {
   $url = KWL_UrlCheck($url);
   if ($url && $img_url) {
      SqlQuery("INSERT INTO $banner_table (url,img_url,alt,rdate) VALUES ('$url','$img_url','$alt',". time() .")");
   }

} elseif ($act == "editok" && $id) {
   $url = KWL_UrlCheck($url);
   $alt = trim($alt);
   if ($url && $img_url) {
      SqlQuery("UPDATE $banner_table SET url = '$url', img_url = '$img_url', alt = '$alt' WHERE id = $id");
   }

} elseif ($act == "active") {
   if (SqlCount("T_Config","Name","Banners")) {
      SqlQuery("UPDATE T_Config SET Value = $Banners WHERE Name = 'Banners'");
   } else {
      SqlQuery("INSERT INTO T_Config (Name,Value) VALUES ('Banners', $Banners)");
   }
   if (SqlCount("T_Config","Name","Banner_location")) {
      SqlQuery("UPDATE T_Config SET Value = $Banner_location WHERE Name = 'Banner_location'");
   } else {
      SqlQuery("INSERT INTO T_Config (Name,Value) VALUES ('Banner_location', $Banner_location)");
   }
   $CONF['Banners'] = $Banners;
   $CONF['Banner_location'] = $Banner_location;

} elseif ($act == "kill" && $id) {
   SqlQuery("DELETE FROM $banner_table WHERE id = $id"); 

} elseif ($act == "scan") {
   $buttons = KWL_GetFileName("$CONF[G_PATH]/$banner_path");
   if (is_array($buttons)) {
      foreach ($buttons as $img) {
         $img_url = "$banner_path/$img";
         if (!SqlCount($banner_table,"img_url",$img_url)) {
            SqlQuery("INSERT INTO $banner_table (img_url,rdate) VALUES ('$img_url',". time() .")");
         }
      }
   }
}

$out = new KWL_Html;
$VAR['Content'] = $out->form_start("admin/banners.php","banners").
                $out->table_start("100%",'',0,0,5).
                "<tr><td>$banner_path/*.* :</td><td>".
                "<a href=\"". $_SERVER['PHP_SELF'] ."?act=scan\">Scan</a></td></tr>".
                "<tr><td>". _BANNER .":</td><td>".
                $out->radio("Banners",array(_NOTUSE,_USE),$CONF['Banners']).
                "</tr><tr><td>". _BANNER_LOCATION .":</td><td>".
                $out->radio("Banner_location",array("header","footer"),$CONF['Banner_location']).
                "<br>(". _BANNER_LOCATION_DESC .
                ")</td></tr><tr><td colspan=\"2\">".
                $out->input_form("hidden","act","active").
                $out->input_form("submit",'',_SAVE_CHANGE).
                "</td></tr>". $out->table_end() . $out->form_end();
                
$VAR['Heading'] = _BANNER;
KWL_DrawMain($VAR);

if ($act == "edit") {
   $rt = SqlQueryFetchArray("select * from $banner_table where id = $id");
   $VAR['Content'] = banner_form($out,$rt);
   $VAR['Heading'] = "<a name=\"banner_edit\">". _BANNER_EDIT ."</a>";
} else {
   $VAR['Content'] = banner_form($out);
   $VAR['Heading'] = _BANNER_ADD;
}
KWL_DrawMain($VAR);

settype($by, "string");
if ($by=="id" || $by=="url" || $by=="alt" || $by=="hits") {
      if ($sort=="asc") { $sort = "$by $sort"; $rsort = "desc"; }
         else if ($sort=="desc") { $sort = "$by $sort"; $rsort = "asc"; }
            else { $sort = "id asc"; $rsort = "desc"; }
} else { $sort = "rdate desc"; $rsort = "desc"; }

$rt = SqlQuery("SELECT * FROM $banner_table ORDER BY $sort");

if (mysql_num_rows($rt)) {
   $VAR['Content'] = $out->table_start("100%",'',1,0,5).
                   "<tr><th><a href=\"". $_SERVER['PHP_SELF'] ."?by=id&sort=$rsort\">no</a></th>".
                   "<th>img</th>".
                   "<th><a href=\"". $_SERVER['PHP_SELF'] ."?by=url&sort=$rsort\">url</a></th>".
                   "<th><a href=\"". $_SERVER['PHP_SELF'] ."?by=alt&sort=$rsort\">". _BANNER_ALT ."</a></th>".
                   "<th><a href=\"". $_SERVER['PHP_SELF'] ."?by=hits&sort=$rsort\">hits</a></th>".
                   "<th>op</th>";
   $no = 1;
   while ($A = mysql_fetch_array($rt)) {
      if (!preg_match('!^http!', $A['img_url'])) $A['img_url'] = "$CONF[G_URL]/$A[img_url]";
      $VAR['Content'] .= "<tr><td>$no</td>".
                       "<td><img src=\"$A[img_url]\" BORDER=\"0\" VSPACE=\"1\" HSPACE=\"1\" ALT=\"". KWL_PrepareHtml($A['alt']) ."\"></td>".
                       "<td><a href=\"$A[url]\" target=\"new\">$A[url]</a></td>".
                       "<td>". KWL_PrepareHtml($A['alt']) ."</td>".
                       "<td>". number_format($A['hits']) ."</td>".
                       "<td><A ONCLICK=\"return getconfirm();\" HREF=\"". $_SERVER['PHP_SELF'] ."?act=kill&id=$A[id]\"><IMG SRC=\"$CONF[img_url]/kill.gif\" ALT=\"kill\" BORDER=\"0\"></A>&nbsp;<A HREF=\"". $_SERVER['PHP_SELF'] ."?act=edit&id=$A[id]#banner_edit\"><IMG SRC=\"$CONF[img_url]/edit.gif\" ALT=\"edit\" BORDER=\"0\"></A></td></tr>";
      $no++;
   }
   $VAR['Content'] .= $out->table_end();
   $VAR['Heading'] = _BANNER;
   KWL_DrawMain($VAR);
}
include("../include/footer.inc.php");

function banner_form($out,$A='') {
   if (is_array($A)) {
      if (!preg_match('!^http!', $A['img_url']))
         $A['img_url'] = KWL_GetConf('G_URL') ."/". $A['img_url'];
      $what = "editok";
   } else {
      $what = "add";
      $A['url'] = $A['img_url'] = $A['alt'] = $A['id'] = "";
   }
   
   return $out->form_start("admin/banners.php","banners").
          $out->table_start("100%",0,0,5).
          "<tr>".
          "<td>* URL:</td>".
          "<td>". $out->input_form("text","url",$A['url'],KWL_FormSize(20),255) ."</td></tr>".
          "<td>* Image URL:</td>".
          "<td>". ($A['img_url'] ? "<img src=\"$A[img_url]\" border=\"0\" vspace=\"1\" hspace=\"1\" /><br />" : "") .
          $out->input_form("text","img_url",$A['img_url'],KWL_FormSize(20),255) ."</td></tr>".
          "<tr><td>". _RANDOM_BUTTON_ALT .":</td>".
          "<td>". $out->input_form("text","alt",KWL_PrepareHtml($A['alt']),KWL_FormSize(20),255) ."</td></tr>".
          "<tr><td colspan=\"2\">".
          $out->input_form("hidden","id",$A['id']).
          $out->input_form("hidden","act",$what).
          $out->input_form("submit",'',_SAVE_CHANGE).
          "</td></tr>". $out->table_end() . $out->form_end();
}
?>
